.. Copyright 2013 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.workflowmodel
--------------------------

.. automodule:: reahl.workflowmodel


Deferred actions
^^^^^^^^^^^^^^^^

DeferredAction
""""""""""""""

.. autoclass:: DeferredAction
   :members:

Requirement
"""""""""""

.. autoclass:: Requirement
   :members:

Tasks and Queues
^^^^^^^^^^^^^^^^


WorkflowInterface
"""""""""""""""""

.. autoclass:: WorkflowInterface
   :members:
   
Queue
"""""

.. autoclass:: Queue
   :members:

Task
""""

.. autoclass:: Task
   :members:

Inbox
"""""

.. autoclass:: Inbox
   :members:
